@@ -1236,7 +1236,6 @@ int config_write_template(const char *file, const struct config *cfg)
 	(void)re_fprintf(f, "#module_app\t\t" "ctrl_tcp" MOD_EXT "\n");
 	(void)re_fprintf(f, "#module_app\t\t" "ctrl_dbus"MOD_EXT"\n");
 	(void)re_fprintf(f, "#module_app\t\t" "httpreq"MOD_EXT"\n");
-	(void)re_fprintf(f, "#module_app\t\t" "multicast"MOD_EXT"\n");
 	(void)re_fprintf(f, "module_app\t\t" "netroam"MOD_EXT"\n");
 	(void)re_fprintf(f, "\n");
 
@@ -1376,17 +1375,6 @@ int config_write_template(const char *file, const struct config *cfg)
 			 "#httpreq_cert\t\tcert.pem\n"
 			 "#httpreq_key\t\tkey.pem\n");
 
-	(void)re_fprintf(f,
-			 "\n# multicast receivers (in priority order)"
-			 "- port number must be even\n"
-			 "#multicast_call_prio\t0\n"
-			 "#multicast_ttl\t1\n"
-			 "#multicast_jbuf_type\tfixed\t\t"
-				"# off, fixed, adaptive\n"
-			 "#multicast_jbuf_delay\t5-10\t\t# frames\n"
-			 "#multicast_listener\t224.0.2.21:50000\n"
-			 "#multicast_listener\t224.0.2.21:50002\n");
-
 	(void)re_fprintf(f,
 			 "\n# avformat\n"
 			 "#avformat_hwaccel\t%s\n"
